@@ -1,5 +1,5 @@
 .onLoad <- function(libname, pkgname) {
-  logger::log_formatter(formatter = glue::glue)
+  logger::log_formatter(formatter = logger::formatter_glue)
 
   return(invisible())
 }
